@echo off
setlocal EnableDelayedExpansion
goto process_start
;Important! Do not modify above this line!

;Begin profile definitions. While all fields are required, of particular importance is the format field, which includes a format description and extension separated by a |. This field is used as a filter when selecting files to convert in the GUI, therefore an incorrectly-formatted format field will result in an inoperable profile!

[PROFILE]
name="AREA-51 (BINK v1)"
format="BINK Video (*.bik)|*.bik"
example="Attract_640x480_30.bik"
description="AREA-51 uses BINK video (version 1) with a base resolution of 640x480.\n\nAll aspect ratios and high-FPS playback are supported natively in-game."
version="1.01"

;Begin menu definitions. MENU0 and MENU1 are reserved for the profile and target directory settings, respectively, therefore profile menus must begin at MENU2. As many menus as defined in the current profile are displayed in the GUI, however only a maximum of 10 arguments may be passed into batch code*. Therefore, menus are limited from 0-9. 
;(*more arguments are possible using the "shift" command, but this is not directly supported by Vidsquish)

;Each menu definition is written as a default string value and one or more 'cases' numbered from 0-infinity. Each case is written as a string label paired with a value which will be passed into batch code. Label and value pairs are separated by a |. All values are passed into batch code as strings. Any unspecified values are treated as -1. The GUI will not allow proceeding until no values equal -1.

;Optionally, each menu definition may also include a text description which will cause a help icon to be displayed beside the menu. Clicking this help icon will display description text defined for the menu. If a description is not declared, a help icon will not be displayed.

[MENU2] ;Aspect ratio
case0="16:9 (HD)|16_9"
case1="16:10 (Golden ratio)|16_10"
case2="21:9 (Ultra-wide)|21_9"
case3="3:2 (Surface)|3_2"
case4="4:3 (Legacy)|4_3"
default="Select aspect ratio"

[MENU3] ;Crop mode
case0="Letterbox/Pillarbox|letterbox"
case1="Crop (Recommended)|crop"
default="Select crop mode"
description="If the selected aspect ratio differs from the original image, this setting determines whether aspect ratio will be preserved (black bars will be added where necessary) or whether the image will be cropped to fill the screen at any aspect ratio.\n\nIf the chosen aspect ratio and the original aspect ratio are the same, this setting will have no effect."

[MENU4] ;Framerate
case0="30 FPS (Original)|fps_30"
case1="60 FPS (Interpolated)|fps_60"
default="Select framerate"
description="AREA-51 cutscenes use a default framerate of 30 FPS. Selecting a higher framerate will interpolate frames for smoother playback, but will significantly increase conversion time."

[MENU5] ;Compression
case0="Low (Original quality)|low"
case1="Medium (Average quality)|medium"
case2="High (Lower quality)|high"
default="Select compression level"
description="Actual output bitrate will vary based on selected settings.\n\n'Low compression' will preserve image quality at similar filesize to original files.\n\n'Medium compression' offers moderate reduction in filesize at slight cost to image quality.\n\n'High compression' produces the smallest possible files, but at noticeable cost to image quality."

;Begin batch processing. All code following the BATCH section will be executed directly once for each file in the target directory, therefore no further .ini definitions should be declared beyond this point.

;Arguments are input in the same order as menus above, where %0 is reserved as the batch file itself and %1 is reserved as the current input file, including the full file path. As such, arguments begin with %2 corresponding to the value set by MENU2.

;Note that profile name is randomized upon execution to support multi-processing. As such, %~n0 can be used when a random string is needed to avoid interfering with other simultaneous processes.

;Also note that batch code is executed from the temporary "%APPDATA%\Vidsquish\lib" directory created at runtime.

[BATCH]
:process_start

REM Get base resolution setting
set width=640
set height=480
set crop_width=!width!
set crop_height=!height!
set crop_left=0
set crop_top=0

REM Get letterbox resolution setting
if %3==letterbox (
    if %2==16_9 (
        set width=854
        set height=480
    )

    if %2==16_10 (
        set width=768
        set height=480   
    )

    if %2==21_9 (
        set width=1138
        set height=480     
    )

    if %2==3_2 (
        set width=720
        set height=480   
    )

    if %2==4_3 (
        set width=640
        set height=480  
    ) 
)

REM Get crop resolution setting
if %3==crop (
    if %2==16_9 (
        set crop_width=640
        set crop_height=360
        set crop_left=0
        set crop_top=60
        set width=!crop_width!
        set height=!crop_height!
    )

    if %2==16_10 (    
        set crop_width=640
        set crop_height=400
        set crop_left=0
        set crop_top=40
        set width=!crop_width!
        set height=!crop_height!
    )

    if %2==21_9 (   
        set crop_width=640
        set crop_height=270
        set crop_left=0
        set crop_top=105
        set width=!crop_width!
        set height=!crop_height! 
    )

    if %2==3_2 (     
        set crop_width=640
        set crop_height=428
        set crop_left=0
        set crop_top=20
        set width=!crop_width!
        set height=!crop_height!
    )

    if %2==4_3 (   
        set crop_width=640
        set crop_height=480
        set crop_left=0
        set crop_top=0
        set width=!crop_width!
        set height=!crop_height!
    )
)

REM Get framerate setting
set framerate=30
if %4==fps_60 (
    set framerate=60
)

REM Get compression setting
set bitrate=97
if %5==medium (
    set bitrate=78
)
if %5==high (
    set bitrate=54
)

REM Get audio quality setting
set audio=3

REM Disable audio processing on silent files
if /i "%~n1"=="MenuBackground_640x480_30" (
    set audio=-1
)
if /i "%~n1"=="StartScreen_640x480_30.bik" (
    goto :process_end
)

REM Cleanup temp files from previous conversions, if any
del /f /q "%~dpn1.bik.tmp"

REM Create preview thumbnail image
if %3==letterbox (
    ffmpeg.exe -ss 00:00:01 -i %1 -y -frames 1 -q:v 5 -vf "scale=(iw*sar)*min(!width!/(iw*sar)\,!height!/ih):ih*min(!width!/(iw*sar)\,!height!/ih), pad=!width!:!height!:(!width!-iw*min(!width!/iw\,!height!/ih))/2:(!height!-ih*min(!width!/iw\,!height!/ih))/2" "%~dp1preview.jpg"
)
if %3==crop (
    ffmpeg.exe -ss 00:00:01 -i %1 -y -frames 1 -q:v 5 -vf "crop=!crop_width!:!crop_height!:!crop_left!:!crop_top!, scale=!width!:!height!" "%~dp1preview.jpg"
)

REM Convert letterbox file
if %3==letterbox (
    if %4==fps_30 (
        REM Convert file with original framerate
        ffmpeg.exe -i %1 -y -q 1 -threads 16 -vf "scale=(iw*sar)*min(!width!/(iw*sar)\,!height!/ih):ih*min(!width!/(iw*sar)\,!height!/ih), pad=!width!:!height!:(!width!-iw*min(!width!/iw\,!height!/ih))/2:(!height!-ih*min(!width!/iw\,!height!/ih))/2, scale=640:480" "%~dpn1_0.avi"
    ) else (
        REM Convert file with interpolated framerate
        ffmpeg.exe -i %1 -y -q 1 -threads 16 -vf "scale=(iw*sar)*min(!width!/(iw*sar)\,!height!/ih):ih*min(!width!/(iw*sar)\,!height!/ih), pad=!width!:!height!:(!width!-iw*min(!width!/iw\,!height!/ih))/2:(!height!-ih*min(!width!/iw\,!height!/ih))/2, scale=640:480, minterpolate='fps=!framerate!'" "%~dpn1_0.avi"
    )
)

REM Convert crop file
if %3==crop (
    if %4==fps_30 (
        REM Convert file with original framerate
        ffmpeg.exe -i %1 -y -q 1 -threads 16 -vf "crop=!crop_width!:!crop_height!:!crop_left!:!crop_top!, scale=!width!:!height!, scale=640:480" "%~dpn1_0.avi"
    ) else (
        REM Convert file with interpolated framerate
        ffmpeg.exe -i %1 -y -q 1 -threads 16 -vf "crop=!crop_width!:!crop_height!:!crop_left!:!crop_top!, scale=!width!:!height!, scale=640:480, minterpolate='fps=!framerate!'" "%~dpn1_0.avi"
    )
)

REM If process completed successfully...
if exist "%~dpn1_0.avi" (
    REM Add converted file to BINK batch
    echo Binkc "%~dpn1_0.avi" %1 /v100 /d!bitrate! /m2.0 /o /l-1 > "%~dp1%~n0.rlst"

    REM Extract and enqueue audio, if enabled
    if not !audio!==-1 (
        ffmpeg.exe -i %1 -y -q 1 -threads 16 -map 0:1 "%~dpn1_1.mp3" -map 0:2? "%~dpn1_2.mp3" -map 0:3? "%~dpn1_3.mp3" -map 0:4? "%~dpn1_4.mp3" -map 0:5? "%~dpn1_5.mp3"

        REM add extracted audio to BINK batch
        echo BinkMix %1 "%~dpn1_1.mp3" %1 /o /l!audio! /t0 /r41000 /b16 /c2 >> "%~dp1%~n0.rlst"
        echo BinkMix %1 "%~dpn1_2.mp3" %1 /o /l!audio! /t1 /r41000 /b16 /c2 >> "%~dp1%~n0.rlst"
        echo BinkMix %1 "%~dpn1_3.mp3" %1 /o /l!audio! /t2 /r41000 /b16 /c2 >> "%~dp1%~n0.rlst"
        echo BinkMix %1 "%~dpn1_4.mp3" %1 /o /l!audio! /t3 /r41000 /b16 /c2 >> "%~dp1%~n0.rlst"
        echo BinkMix %1 "%~dpn1_5.mp3" %1 /o /l!audio! /t4 /r41000 /b16 /c2 >> "%~dp1%~n0.rlst"
    )

    REM Set BINK batch to end automatically
    echo taskkill /f /fi "WINDOWTITLE eq %~n0" /t >> "%~dp1%~n0.rlst"

    REM Execute BINK batch with custom process ID
    start /wait /min "%~n0" cmd /c "radvideo64.exe radbatch "%~dp1%~n0.rlst" /R"

    REM Delete converted source files
    del /f /q "%~dpn1*.avi"
    del /f /q "%~dpn1*.mp3"

    REM Delete BINK batch file
    del /f /q "%~dp1%~n0.rlst"
)

REM Remove completed file from project.vs2
:process_end
echo %1 >> "%~dpn0.vs2"
